@@ -4,7 +4,10 @@ import biobricks as bb
 import click
 from logger import logger
 from pathlib import Path
-from .bblib import read_config, write_config, init_bblib, check_token
+import pathlib as pl, yaml, pkg_resources
+from .config import read_config, write_config, init_bblib
+from .checks import check_token
+from .brick import Brick
 
 @click.group()
 def cli():
@@ -52,20 +55,54 @@ def configure():
 
 @cli.command(help="Initialize a .bb directory for data dependencies")
 def init():
-    bb.bb_init()
+    location = ".bb"
+    dotbb = pl.Path(location)
+    if dotbb.exists():
+        return
+    dotbb.mkdir()
+    
+    with open(dotbb / ".gitignore", "w") as f: 
+        f.write("/*/") # ignore all subdirectories
+
+def local_bblib():
+    return Path(".bb")
+
+def check_has_local_bblib():
+    if not local_bblib().exists():
+        raise Exception(".bb not found. run `biobricks init` first.")
+
+def symlink_local_brick(brick):
+    check_has_local_bblib()
+    localpath = local_bblib() / brick.urlpath()
+    localpath.mkdir(parents=True, exist_ok=True)
+
+    brick.path().symlink_to(localpath, target_is_directory=True)
+
+    # write a line to the dependencies file recording this import
+    with open(local_bblib() / "dependencies.txt", "a") as f:
+        f.write(f"{brick.url()}")
 
 @cli.command(name="import",help="Import a data dependency into the .bb directory")
-def import_(brick,org="biobricks-ai",location=".bb"):
-    bb.bb_import(brick,org,location)
+def import_(ref):
+    check_has_local_bblib()
+    brick : Brick = install(ref) 
+    symlink_local_brick(brick)
+    
+@cli.command(name="pull", help="install all the local dependencies")
+def pull():
+    check_has_local_bblib()
+    with open(local_bblib() / "dependencies.txt", "r") as f:
+        for line in f.readlines():
+            Brick.FromURL(line).install()
 
 @cli.command(help="Install a data dependency into $BBLIB")
-@click.argument('args', nargs=-1)
-def install(args):
-    bb.pull(*args)
+@click.argument("ref",type=str)
+def install(ref):
+    return Brick.Resolve(ref, force_remote=True).install()
 
 @cli.command(help="Show the status of BBLIB")
 def status():
-    logger.info("BBLIB: " + str(bb.bblib()))
+    print("BBLIB: " + str(bb.bblib()))
 
 if __name__ == "__main__":
     cli()
